@@ -314,6 +314,24 @@ pub enum NodeLayout {
     None,
 }
 
+#[non_exhaustive]
+#[derive(Clone, Copy, Debug, PartialEq, Deserialize, Serialize)]
+#[serde(rename_all = "snake_case")]
+pub enum Floating {
+    AutoOn,
+    AutoOff,
+    UserOn,
+    UserOff,
+}
+
+#[non_exhaustive]
+#[derive(Clone, Copy, Debug, PartialEq, Deserialize, Serialize)]
+#[serde(rename_all = "lowercase")]
+pub enum ScratchpadState {
+    Fresh,
+    None,
+}
+
 #[non_exhaustive]
 #[derive(Clone, Debug, PartialEq, Deserialize, Serialize)]
 pub struct Node {
@@ -353,6 +371,8 @@ pub struct Node {
     pub focused: bool,
     /// Array of child node IDs in the current focus order.
     pub focus: Vec<i64>,
+    /// Floating state of container, i3 specific property
+    pub floating: Option<Floating>,
     /// The tiling children nodes for the node.
     #[serde(default)]
     pub nodes: Vec<Node>,
@@ -364,9 +384,12 @@ pub struct Node {
     /// that can be used as an aid in submitting reproduction steps for bug
     /// reports.
     pub representation: Option<String>,
-    /// (Only containers and views) The fullscreen mode of the node. 0 means
+    /// (Only views) The fullscreen mode of the node. 0 means
     /// none, 1 means full workspace, and 2 means global fullscreen.
     pub fullscreen_mode: Option<u8>,
+    /// (Only views) For an xdg-shell and xwayland view, whether the window is in the scratchpad.
+    /// Otherwise, null.
+    pub scratchpad_state: Option<ScratchpadState>,
     /// (Only views) For an xdg-shell view, the name of the application, if set.
     /// Otherwise, null.
     pub app_id: Option<String>,
